@@ -160,9 +160,9 @@ writeData <- function(wb,
   exDigits <- getOption("digits")
   options("digits" = 22)
   on.exit(options("digits" = exDigits), add = TRUE)
-
   
-    
+  
+  
   if(is.null(x))
     return(invisible(0))
   
@@ -191,7 +191,7 @@ writeData <- function(wb,
   ## borderColours validation
   borderColour <- validateColour(borderColour, "Invalid border colour")
   borderStyle <- validateBorderStyle(borderStyle)[[1]]
-    
+  
   ## special case - vector of hyperlinks
   hlinkNames <- NULL
   if("hyperlink" %in% class(x)){
@@ -205,7 +205,7 @@ writeData <- function(wb,
     class(x[[1]]) <- "formula"
     colNames = FALSE
   }
-
+  
   ## named region
   if(!is.null(name)){ ## validate name
     ex_names <- regmatches(wb$workbook$definedNames, regexpr('(?<=name=")[^"]+', wb$workbook$definedNames, perl = TRUE))
@@ -224,26 +224,37 @@ writeData <- function(wb,
     colNames <- FALSE ## this will go to coerce.default and rowNames will be ignored 
   
   ## Coerce to data.frame
-  x <- openxlsxCoerce(x, rowNames)
-    
+  x <- openxlsxCoerce(x = x, rowNames = rowNames)
+  
   nCol <- ncol(x)
   nRow <- nrow(x)
   
   ## If no rows and not writing column names return as nothing to write
   if(nRow == 0 & !colNames)
     return(invisible(0))
-    
+  
   colClasses <- lapply(x, function(x) tolower(class(x)))
   colClasss2 <- colClasses
   colClasss2[sapply(colClasses, function(x) "formula" %in% x) & sapply(colClasses, function(x) "hyperlink" %in% x)] <- "formula"
-    
+  
   
   sheetX <- wb$validateSheet(sheet)
   if(wb$isChartSheet[[sheetX]]){
     stop("Cannot write to chart sheet.")
     return(NULL)
   }
-
+  
+  
+  ## Check not overwriting existing table headers
+  wb$check_overwrite_tables(sheet = sheet
+                            , new_rows = c(startRow, startRow + nRow - 1L + colNames)
+                            , new_cols = c(startCol, startCol + nCol - 1L)
+                            , check_table_header_only = TRUE
+                            , error_msg = 
+                              "Cannot overwrite table headers. Avoid writing over the header row or see getTables() & removeTables() to remove the table object.")
+  
+  
+  
   ## write autoFilter, can only have a single filter per worksheet
   if(withFilter){
     
@@ -251,10 +262,10 @@ writeData <- function(wb,
     ref <- paste(getCellRefs(coords), collapse = ":")
     
     wb$worksheets[[sheetX]]$autoFilter <- sprintf('<autoFilter ref="%s"/>', ref)
-    
-    l <- .Call("openxlsx_convert_to_excel_ref", unlist(coords[,2]), LETTERS, PACKAGE="openxlsx")
-    dfn <- sprintf("'%s'!%s", names(wb)[sheetX],  paste0("$", l, "$", coords[,1], collapse=":"))
 
+    l <- convert_to_excel_ref(cols = unlist(coords[,2]), LETTERS = LETTERS)
+    dfn <- sprintf("'%s'!%s", names(wb)[sheetX],  paste0("$", l, "$", coords[,1], collapse=":"))
+    
     dn <- sprintf('<definedName name="_xlnm._FilterDatabase" localSheetId="%s" hidden="1">%s</definedName>', sheetX - 1L, dfn)
     
     if(length(wb$workbook$definedNames) > 0){
@@ -267,9 +278,9 @@ writeData <- function(wb,
       wb$workbook$definedNames <- dn
     }
     
-      
-  }
     
+  }
+  
   ## write data.frame
   wb$writeData(df = x,
                colNames = colNames,
@@ -286,7 +297,7 @@ writeData <- function(wb,
     addStyle(wb = wb, sheet = sheet, style=headerStyle,
              rows = startRow,
              cols = 0:(nCol-1) + startCol,
-             gridExpand = TRUE)
+             gridExpand = TRUE, stack = TRUE)
   
   ## If we don't have any rows to write return
   if(nRow == 0)
@@ -295,8 +306,8 @@ writeData <- function(wb,
   ## named region
   if(!is.null(name)){
     
-    ref1 <- paste0("$", .Call("openxlsx_convert_to_excel_ref", startCol, LETTERS), "$", startRow)
-    ref2 <- paste0("$", .Call("openxlsx_convert_to_excel_ref", startCol + nCol - 1L, LETTERS), "$", startRow + nRow - 1L + colNames)
+    ref1 <- paste0("$", .Call("openxlsx_convert_to_excel_ref", startCol, LETTERS, PACKAGE = "openxlsx"), "$", startRow)
+    ref2 <- paste0("$", .Call("openxlsx_convert_to_excel_ref", startCol + nCol - 1L, LETTERS, PACKAGE = "openxlsx"), "$", startRow + nRow - 1L + colNames)
     wb$createNamedRegion(ref1 = ref1, ref2 = ref2, name = name, sheet = wb$sheet_names[sheet])
     
   }
@@ -305,7 +316,7 @@ writeData <- function(wb,
   ## hyperlink style, if no borders
   if(borders == "none"){
     
-    invisible(classStyles(wb, sheet = sheet, startRow = startRow, startCol = startCol, colNames = colNames, nRow = nrow(x), colClasses = colClasses))
+    invisible(classStyles(wb, sheet = sheet, startRow = startRow, startCol = startCol, colNames = colNames, nRow = nrow(x), colClasses = colClasses, stack = TRUE))
     
   }else if(borders == "surrounding"){
     
@@ -438,7 +449,7 @@ writeFormula <- function(wb,
                          startCol = 1,
                          startRow = 1, 
                          xy = NULL){
-
+  
   if(!"character" %in% class(x))
     stop("x must be a character vector.")
   
@@ -447,8 +458,8 @@ writeFormula <- function(wb,
   
   if(any(grepl("^(=|)HYPERLINK\\(", x, ignore.case = TRUE)))
     class(dfx$X) <- c("character", "formula", "hyperlink")
-    
-    
+  
+  
   
   writeData(wb = wb,
             sheet = sheet,
